==> ejc-settlementmanage-impl-3.0.0-20220420.035439-5-sources.jar: com/ejianc/business/settlementmanage/bean/SubcontractCountersignedEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.settlementmanage.bean.SubcontractCountersignedDetilesEntity;
/**
 * 分包结算条件会签单-主表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_settlementmanage_subcontract_countersigned")
public class SubcontractCountersignedEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="subcontracted_project_id")
    private java.lang.Long subcontractedProjectId; // 分包工程ID
    @TableField(value="subcontracted_project_name")
    private java.lang.String subcontractedProjectName; // 分包工程名称
    @TableField(value="subcontract_project_manager_id")
    private java.lang.Long subcontractProjectManagerId; // 分包项目经理ID
    @TableField(value="subcontract_project_manager_name")
    private java.lang.String subcontractProjectManagerName; // 分包项目经理名称
    @TableField(value="phone")
    private java.lang.String phone; // 联系电话
    @TableField(value="id_card")
    private java.lang.String idCard; // 身份证号码
    @TableField(value="contract_code")
    private java.lang.String contractCode; // 合同编码
    @TableField(value="subcontract_pricing_method")
    private java.lang.String subcontractPricingMethod; // 分包计价方式
    @TableField(value="original_contract_price")
    private java.math.BigDecimal originalContractPrice; // 原合同价
    @TableField(value="project_settlement_price")
    private java.math.BigDecimal projectSettlementPrice; // 分包商结算书送审总造价
    @TableField(value="project_settlement")
    private java.math.BigDecimal projectSettlement; // 分包商工程结算书(式)
    @TableField(value="sending_date")
    private java.util.Date sendingDate; // 送签日期
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人id
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人名称

    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="project_settlementf")
    private java.lang.Integer projectSettlementf; // 分包商工程结算书(份)
    @TableField(value="agent_department")
    private java.lang.Long agentDepartment; // 经办人部门
    @TableField(value="made_id")
    private java.lang.Long madeId; // 分包人id
    @TableField(value="made_name")
    private java.lang.String madeName; // 分包人名称
    @TableField(value="made_address")
    private java.lang.String madeAddress; // 分包人单位地址
    @TableField(value="qualification")
    private java.lang.String qualification; // 企业资质
    @TableField(value="postcode")
    private java.lang.String postcode; // 邮政编码
    @TableField(value="content")
    private java.lang.String content; // 联系人
    @TableField(value="sub_phone")
    private java.lang.String subPhone; // 分包人联系电话
    @TableField(value="fax")
    private java.lang.String fax; // 联系传真
    @TableField(value="nature")
    private java.lang.String nature; // 企业性质
    @TableField(value="legal")
    private java.lang.String legal; // 法人代表
    @TableField(value="legal_phone")
    private java.lang.String legalPhone; // 法人联系电话
    @TableField(value="contract_type")
    private java.lang.String contractType; // 合同类型
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="subcontractCountersignedDetilesService",pidName = "mid")
    private List<SubcontractCountersignedDetilesEntity> subcontractCountersignedDetilesEntities = new ArrayList<>(); // 分包结算条件会签单-子表
    

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 分包工程ID
     */
    public java.lang.Long getSubcontractedProjectId() {
        return subcontractedProjectId;
    }

    /**
     * 分包工程ID
     */
    public void setSubcontractedProjectId(java.lang.Long subcontractedProjectId) {
        this.subcontractedProjectId = subcontractedProjectId;
    }
    /**
     * 分包工程名称
     */
    public java.lang.String getSubcontractedProjectName() {
        return subcontractedProjectName;
    }

    /**
     * 分包工程名称
     */
    public void setSubcontractedProjectName(java.lang.String subcontractedProjectName) {
        this.subcontractedProjectName = subcontractedProjectName;
    }
    /**
     * 分包项目经理ID
     */
    public java.lang.Long getSubcontractProjectManagerId() {
        return subcontractProjectManagerId;
    }

    /**
     * 分包项目经理ID
     */
    public void setSubcontractProjectManagerId(java.lang.Long subcontractProjectManagerId) {
        this.subcontractProjectManagerId = subcontractProjectManagerId;
    }
    /**
     * 分包项目经理名称
     */
    public java.lang.String getSubcontractProjectManagerName() {
        return subcontractProjectManagerName;
    }

    /**
     * 分包项目经理名称
     */
    public void setSubcontractProjectManagerName(java.lang.String subcontractProjectManagerName) {
        this.subcontractProjectManagerName = subcontractProjectManagerName;
    }
    /**
     * 联系电话
     */
    public java.lang.String getPhone() {
        return phone;
    }

    /**
     * 联系电话
     */
    public void setPhone(java.lang.String phone) {
        this.phone = phone;
    }
    /**
     * 身份证号码
     */
    public java.lang.String getIdCard() {
        return idCard;
    }

    /**
     * 身份证号码
     */
    public void setIdCard(java.lang.String idCard) {
        this.idCard = idCard;
    }
    /**
     * 合同编码
     */
    public java.lang.String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编码
     */
    public void setContractCode(java.lang.String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 分包计价方式
     */
    public java.lang.String getSubcontractPricingMethod() {
        return subcontractPricingMethod;
    }

    /**
     * 分包计价方式
     */
    public void setSubcontractPricingMethod(java.lang.String subcontractPricingMethod) {
        this.subcontractPricingMethod = subcontractPricingMethod;
    }
    /**
     * 原合同价
     */
    public java.math.BigDecimal getOriginalContractPrice() {
        return originalContractPrice;
    }

    /**
     * 原合同价
     */
    public void setOriginalContractPrice(java.math.BigDecimal originalContractPrice) {
        this.originalContractPrice = originalContractPrice;
    }
    /**
     * 分包商结算书送审总造价
     */
    public java.math.BigDecimal getProjectSettlementPrice() {
        return projectSettlementPrice;
    }

    /**
     * 分包商结算书送审总造价
     */
    public void setProjectSettlementPrice(java.math.BigDecimal projectSettlementPrice) {
        this.projectSettlementPrice = projectSettlementPrice;
    }
    /**
     * 分包商工程结算书(式)
     */
    public java.math.BigDecimal getProjectSettlement() {
        return projectSettlement;
    }

    /**
     * 分包商工程结算书(式)
     */
    public void setProjectSettlement(java.math.BigDecimal projectSettlement) {
        this.projectSettlement = projectSettlement;
    }
    /**
     * 送签日期
     */
    public java.util.Date getSendingDate() {
        return sendingDate;
    }

    /**
     * 送签日期
     */
    public void setSendingDate(java.util.Date sendingDate) {
        this.sendingDate = sendingDate;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人名称
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }



    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 分包商工程结算书(份)
     */
    public java.lang.Integer getProjectSettlementf() {
        return projectSettlementf;
    }

    /**
     * 分包商工程结算书(份)
     */
    public void setProjectSettlementf(java.lang.Integer projectSettlementf) {
        this.projectSettlementf = projectSettlementf;
    }
    /**
     * 经办人部门
     */
    public java.lang.Long getAgentDepartment() {
        return agentDepartment;
    }

    /**
     * 经办人部门
     */
    public void setAgentDepartment(java.lang.Long agentDepartment) {
        this.agentDepartment = agentDepartment;
    }
    /**
     * 分包人id
     */
    public java.lang.Long getMadeId() {
        return madeId;
    }

    /**
     * 分包人id
     */
    public void setMadeId(java.lang.Long madeId) {
        this.madeId = madeId;
    }
    /**
     * 分包人名称
     */
    public java.lang.String getMadeName() {
        return madeName;
    }

    /**
     * 分包人名称
     */
    public void setMadeName(java.lang.String madeName) {
        this.madeName = madeName;
    }
    /**
     * 分包人单位地址
     */
    public java.lang.String getMadeAddress() {
        return madeAddress;
    }

    /**
     * 分包人单位地址
     */
    public void setMadeAddress(java.lang.String madeAddress) {
        this.madeAddress = madeAddress;
    }
    /**
     * 企业资质
     */
    public java.lang.String getQualification() {
        return qualification;
    }

    /**
     * 企业资质
     */
    public void setQualification(java.lang.String qualification) {
        this.qualification = qualification;
    }
    /**
     * 邮政编码
     */
    public java.lang.String getPostcode() {
        return postcode;
    }

    /**
     * 邮政编码
     */
    public void setPostcode(java.lang.String postcode) {
        this.postcode = postcode;
    }
    /**
     * 联系人
     */
    public java.lang.String getContent() {
        return content;
    }

    /**
     * 联系人
     */
    public void setContent(java.lang.String content) {
        this.content = content;
    }
    /**
     * 分包人联系电话
     */
    public java.lang.String getSubPhone() {
        return subPhone;
    }

    /**
     * 分包人联系电话
     */
    public void setSubPhone(java.lang.String subPhone) {
        this.subPhone = subPhone;
    }
    /**
     * 联系传真
     */
    public java.lang.String getFax() {
        return fax;
    }

    /**
     * 联系传真
     */
    public void setFax(java.lang.String fax) {
        this.fax = fax;
    }
    /**
     * 企业性质
     */
    public java.lang.String getNature() {
        return nature;
    }

    /**
     * 企业性质
     */
    public void setNature(java.lang.String nature) {
        this.nature = nature;
    }
    /**
     * 法人代表
     */
    public java.lang.String getLegal() {
        return legal;
    }

    /**
     * 法人代表
     */
    public void setLegal(java.lang.String legal) {
        this.legal = legal;
    }
    /**
     * 法人联系电话
     */
    public java.lang.String getLegalPhone() {
        return legalPhone;
    }

    /**
     * 法人联系电话
     */
    public void setLegalPhone(java.lang.String legalPhone) {
        this.legalPhone = legalPhone;
    }
    
    /**
     * 分包结算条件会签单-子表
     */
    public List<SubcontractCountersignedDetilesEntity> getSubcontractCountersignedDetilesEntities() {
        return subcontractCountersignedDetilesEntities;
    }

    /**
     * 分包结算条件会签单-子表
     */
    public void setSubcontractCountersignedDetilesEntities(List<SubcontractCountersignedDetilesEntity> subcontractCountersignedDetilesEntities) {
        this.subcontractCountersignedDetilesEntities = subcontractCountersignedDetilesEntities;
    }

    public String getContractType() {
        return contractType;
    }

    public void setContractType(String contractType) {
        this.contractType = contractType;
    }
}

==> ejc-settlementmanage-impl-3.0.0-20220429.013833-19-sources.jar: com/ejianc/business/settlementmanage/bean/SubcontractCountersignedEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.settlementmanage.bean.SubcontractCountersignedDetilesEntity;
/**
 * 分包结算条件会签单-主表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_settlementmanage_subcontract_countersigned")
public class SubcontractCountersignedEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="subcontracted_project_id")
    private java.lang.Long subcontractedProjectId; // 分包工程ID
    @TableField(value="subcontracted_project_name")
    private java.lang.String subcontractedProjectName; // 分包工程名称
    @TableField(value="subcontract_project_manager_id")
    private java.lang.Long subcontractProjectManagerId; // 分包项目经理ID
    @TableField(value="subcontract_project_manager_name")
    private java.lang.String subcontractProjectManagerName; // 分包项目经理名称
    @TableField(value="phone")
    private java.lang.String phone; // 联系电话
    @TableField(value="id_card")
    private java.lang.String idCard; // 身份证号码
    @TableField(value="contract_code")
    private java.lang.String contractCode; // 合同编码
    @TableField(value="subcontract_pricing_method")
    private java.lang.String subcontractPricingMethod; // 分包计价方式
    @TableField(value="original_contract_price")
    private java.math.BigDecimal originalContractPrice; // 原合同价
    @TableField(value="project_settlement_price")
    private java.math.BigDecimal projectSettlementPrice; // 分包商结算书送审总造价
    @TableField(value="project_settlement")
    private java.math.BigDecimal projectSettlement; // 分包商工程结算书(式)
    @TableField(value="sending_date")
    private java.util.Date sendingDate; // 送签日期
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人id
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人名称

    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="project_settlementf")
    private java.lang.Integer projectSettlementf; // 分包商工程结算书(份)
    @TableField(value="agent_department")
    private java.lang.Long agentDepartment; // 经办人部门
    @TableField(value="made_id")
    private java.lang.Long madeId; // 分包人id
    @TableField(value="made_name")
    private java.lang.String madeName; // 分包人名称
    @TableField(value="made_address")
    private java.lang.String madeAddress; // 分包人单位地址
    @TableField(value="qualification")
    private java.lang.String qualification; // 企业资质
    @TableField(value="postcode")
    private java.lang.String postcode; // 邮政编码
    @TableField(value="content")
    private java.lang.String content; // 联系人
    @TableField(value="sub_phone")
    private java.lang.String subPhone; // 分包人联系电话
    @TableField(value="fax")
    private java.lang.String fax; // 联系传真
    @TableField(value="nature")
    private java.lang.String nature; // 企业性质
    @TableField(value="legal")
    private java.lang.String legal; // 法人代表
    @TableField(value="legal_phone")
    private java.lang.String legalPhone; // 法人联系电话
    @TableField(value="contract_type")
    private java.lang.String contractType; // 合同类型
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称

    
    @TableField(exist=false)
    @SubEntity(serviceName="subcontractCountersignedDetilesService",pidName = "mid")
    private List<SubcontractCountersignedDetilesEntity> subcontractCountersignedDetilesEntities = new ArrayList<>(); // 分包结算条件会签单-子表
    

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 分包工程ID
     */
    public java.lang.Long getSubcontractedProjectId() {
        return subcontractedProjectId;
    }

    /**
     * 分包工程ID
     */
    public void setSubcontractedProjectId(java.lang.Long subcontractedProjectId) {
        this.subcontractedProjectId = subcontractedProjectId;
    }
    /**
     * 分包工程名称
     */
    public java.lang.String getSubcontractedProjectName() {
        return subcontractedProjectName;
    }

    /**
     * 分包工程名称
     */
    public void setSubcontractedProjectName(java.lang.String subcontractedProjectName) {
        this.subcontractedProjectName = subcontractedProjectName;
    }
    /**
     * 分包项目经理ID
     */
    public java.lang.Long getSubcontractProjectManagerId() {
        return subcontractProjectManagerId;
    }

    /**
     * 分包项目经理ID
     */
    public void setSubcontractProjectManagerId(java.lang.Long subcontractProjectManagerId) {
        this.subcontractProjectManagerId = subcontractProjectManagerId;
    }
    /**
     * 分包项目经理名称
     */
    public java.lang.String getSubcontractProjectManagerName() {
        return subcontractProjectManagerName;
    }

    /**
     * 分包项目经理名称
     */
    public void setSubcontractProjectManagerName(java.lang.String subcontractProjectManagerName) {
        this.subcontractProjectManagerName = subcontractProjectManagerName;
    }
    /**
     * 联系电话
     */
    public java.lang.String getPhone() {
        return phone;
    }

    /**
     * 联系电话
     */
    public void setPhone(java.lang.String phone) {
        this.phone = phone;
    }
    /**
     * 身份证号码
     */
    public java.lang.String getIdCard() {
        return idCard;
    }

    /**
     * 身份证号码
     */
    public void setIdCard(java.lang.String idCard) {
        this.idCard = idCard;
    }
    /**
     * 合同编码
     */
    public java.lang.String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编码
     */
    public void setContractCode(java.lang.String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 分包计价方式
     */
    public java.lang.String getSubcontractPricingMethod() {
        return subcontractPricingMethod;
    }

    /**
     * 分包计价方式
     */
    public void setSubcontractPricingMethod(java.lang.String subcontractPricingMethod) {
        this.subcontractPricingMethod = subcontractPricingMethod;
    }
    /**
     * 原合同价
     */
    public java.math.BigDecimal getOriginalContractPrice() {
        return originalContractPrice;
    }

    /**
     * 原合同价
     */
    public void setOriginalContractPrice(java.math.BigDecimal originalContractPrice) {
        this.originalContractPrice = originalContractPrice;
    }
    /**
     * 分包商结算书送审总造价
     */
    public java.math.BigDecimal getProjectSettlementPrice() {
        return projectSettlementPrice;
    }

    /**
     * 分包商结算书送审总造价
     */
    public void setProjectSettlementPrice(java.math.BigDecimal projectSettlementPrice) {
        this.projectSettlementPrice = projectSettlementPrice;
    }
    /**
     * 分包商工程结算书(式)
     */
    public java.math.BigDecimal getProjectSettlement() {
        return projectSettlement;
    }

    /**
     * 分包商工程结算书(式)
     */
    public void setProjectSettlement(java.math.BigDecimal projectSettlement) {
        this.projectSettlement = projectSettlement;
    }
    /**
     * 送签日期
     */
    public java.util.Date getSendingDate() {
        return sendingDate;
    }

    /**
     * 送签日期
     */
    public void setSendingDate(java.util.Date sendingDate) {
        this.sendingDate = sendingDate;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人名称
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }


    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 分包商工程结算书(份)
     */
    public java.lang.Integer getProjectSettlementf() {
        return projectSettlementf;
    }

    /**
     * 分包商工程结算书(份)
     */
    public void setProjectSettlementf(java.lang.Integer projectSettlementf) {
        this.projectSettlementf = projectSettlementf;
    }
    /**
     * 经办人部门
     */
    public java.lang.Long getAgentDepartment() {
        return agentDepartment;
    }

    /**
     * 经办人部门
     */
    public void setAgentDepartment(java.lang.Long agentDepartment) {
        this.agentDepartment = agentDepartment;
    }
    /**
     * 分包人id
     */
    public java.lang.Long getMadeId() {
        return madeId;
    }

    /**
     * 分包人id
     */
    public void setMadeId(java.lang.Long madeId) {
        this.madeId = madeId;
    }
    /**
     * 分包人名称
     */
    public java.lang.String getMadeName() {
        return madeName;
    }

    /**
     * 分包人名称
     */
    public void setMadeName(java.lang.String madeName) {
        this.madeName = madeName;
    }
    /**
     * 分包人单位地址
     */
    public java.lang.String getMadeAddress() {
        return madeAddress;
    }

    /**
     * 分包人单位地址
     */
    public void setMadeAddress(java.lang.String madeAddress) {
        this.madeAddress = madeAddress;
    }
    /**
     * 企业资质
     */
    public java.lang.String getQualification() {
        return qualification;
    }

    /**
     * 企业资质
     */
    public void setQualification(java.lang.String qualification) {
        this.qualification = qualification;
    }
    /**
     * 邮政编码
     */
    public java.lang.String getPostcode() {
        return postcode;
    }

    /**
     * 邮政编码
     */
    public void setPostcode(java.lang.String postcode) {
        this.postcode = postcode;
    }
    /**
     * 联系人
     */
    public java.lang.String getContent() {
        return content;
    }

    /**
     * 联系人
     */
    public void setContent(java.lang.String content) {
        this.content = content;
    }
    /**
     * 分包人联系电话
     */
    public java.lang.String getSubPhone() {
        return subPhone;
    }

    /**
     * 分包人联系电话
     */
    public void setSubPhone(java.lang.String subPhone) {
        this.subPhone = subPhone;
    }
    /**
     * 联系传真
     */
    public java.lang.String getFax() {
        return fax;
    }

    /**
     * 联系传真
     */
    public void setFax(java.lang.String fax) {
        this.fax = fax;
    }
    /**
     * 企业性质
     */
    public java.lang.String getNature() {
        return nature;
    }

    /**
     * 企业性质
     */
    public void setNature(java.lang.String nature) {
        this.nature = nature;
    }
    /**
     * 法人代表
     */
    public java.lang.String getLegal() {
        return legal;
    }

    /**
     * 法人代表
     */
    public void setLegal(java.lang.String legal) {
        this.legal = legal;
    }
    /**
     * 法人联系电话
     */
    public java.lang.String getLegalPhone() {
        return legalPhone;
    }

    /**
     * 法人联系电话
     */
    public void setLegalPhone(java.lang.String legalPhone) {
        this.legalPhone = legalPhone;
    }
    
    /**
     * 分包结算条件会签单-子表
     */
    public List<SubcontractCountersignedDetilesEntity> getSubcontractCountersignedDetilesEntities() {
        return subcontractCountersignedDetilesEntities;
    }

    /**
     * 分包结算条件会签单-子表
     */
    public void setSubcontractCountersignedDetilesEntities(List<SubcontractCountersignedDetilesEntity> subcontractCountersignedDetilesEntities) {
        this.subcontractCountersignedDetilesEntities = subcontractCountersignedDetilesEntities;
    }

    public String getContractType() {
        return contractType;
    }

    public void setContractType(String contractType) {
        this.contractType = contractType;
    }
}
